%
% plot_profiles
%
% This script plots composites of temperature, salinity, potential density and sound speed of the casts in a mods data file.
% The final result is four pages of plots; one for each variable.
%
%-------------------------------------------------------------------------------
% Set run parameters.
%
%    hydnam     ... MODS format hydrographic data file.
%    pltttl     ... Title for plot
%    fillnan    ... Fill voids in data with NaN's.  [0] no  [1] yes
%    ifprint    ... Toggle for printing plots [n] no  [y] yes
%    ifwrite    ... Toggle for writing  plots [n] no  [y] yes
%-------------------------------------------------------------------------------

hydnam=input('Enter the file name: ','s');
nchar=length(hydnam)-5;

plttl = input('Enter the plot title: ','s');
nstation=input('How many stations to plot (>999 for all): ');

ifprint = input('Do you want to print the plots (y/n): ','s');
ifwrite = input('Do you want to write the plots (y/n): ','s');
if(ifwrite=='y')
  pltype  = input('Write plot in Postscript or PNG (ps/pn)  : ','s');
end

plot_num = input('Do you want 1 or 4 plots per page (1/4): ');

disp('This script plots temperature, salinity, density and choice of sound speed or T vs S')
plchoice = input('Plot sound speed or T vs S (ss/ts)  : ','s');

fillnan=1;
[header,hinfo,htype,z,t,s]=rhydro(hydnam,fillnan);

sspd = sw_svel(s,t,z);
pden = sw_pden(s,t,z,0) - 1000.;

if nstation >= 999 
  [nstation npts] = size(t);
  icntr = 1:nstation;
else
  if(length(unique(hinfo(:,3)))~=length(hinfo(:,3)))
     disp('Station IDs must be unique')
     return
  end
  icntr=input('Enter the station ids (within brackets): ');
  for i=1:nstation
     dum=find(hinfo(:,3)==icntr(i));
     icntr(i)=dum(1);
  end
end

%
% plot the data
%

switch plot_num
case 1

%
% temperature vs depth
%

figure
plot(t(icntr,:)',-z(icntr,:)'),grid on,
title(plttl,'fontsize',13,'interp','none'),hold on,label_cast(icntr,t,-z,hinfo)
xlabel('Temperature')
ylabel('Depth')
orient tall

%
% salinity vs depth
%

figure
plot(s(icntr,:)',-z(icntr,:)'),grid on,
title(plttl,'fontsize',13,'interp','none'),hold on,label_cast(icntr,s,-z,hinfo)
xlabel('Salinity')
ylabel('Depth')
orient tall

%
% density  vs depth
%

figure
plot(pden(icntr,:)',-z(icntr,:)'),grid on,
title(plttl,'fontsize',13,'interp','none'),hold on,label_cast(icntr,pden,-z,hinfo)
xlabel('Density')
ylabel('Depth')
orient tall

switch lower(plchoice)

case 'ss'

%
% sound speed vs depth
%

figure
plot(sspd(icntr,:)',-z(icntr,:)'),grid on,
title(plttl,'fontsize',13,'interp','none'),hold on,label_cast(icntr,sspd,-z,hinfo)
xlabel('Sound Speed')
ylabel('Depth')
orient tall

case 'ts'

%
% temperature vs salinity
%

figure
plot(s(icntr,:)',t(icntr,:)'),grid on,
title(plttl,'fontsize',13,'interp','none'),hold on,label_cast(icntr,sspd,-z,hinfo)
xlabel('Salinity')
ylabel('Temperature')
orient tall

end

%
% print/write
%

if(ifprint=='y')
   figure(1);print -dpsc -Pmseasclr1
   figure(2);print -dpsc -Pmseasclr1
   figure(3);print -dpsc -Pmseasclr1
   figure(4);print -dpsc -Pmseasclr1
end

if(ifwrite=='y')
    figure(1)
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_tz.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_tz.png'];
       print('-dpng',outfile)
    end
    figure(2)
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_sz.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_sz.png'];
       print('-dpng',outfile)
    end
    figure(3)
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_rz.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_rz.png'];
       print('-dpng',outfile)
    end
    figure(4)
    if(pltype=='ps')
       switch lower(plchoice)
       case 'ss'
       outfile=[hydnam(1:nchar),'_cz.ps'];
       case 'ts'
       outfile=[hydnam(1:nchar),'_ts.ps'];
       end
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       switch lower(plchoice)
       case 'ss'
       outfile=[hydnam(1:nchar),'_cz.png'];
       case 'ts'
       outfile=[hydnam(1:nchar),'_ts.png'];
       end
       print('-dpng',outfile)
    end
end

case 4

%
% plot the data
%

figure

subplot(2,2,1),plot(t(icntr,:)',-z(icntr,:)'),grid on,
 title('T(z)','fontsize',13),hold on,label_cast(icntr,t,-z,hinfo)

subplot(2,2,2),plot(s(icntr,:)',-z(icntr,:)'),grid on,
 title('S(z)','fontsize',13),hold on,label_cast(icntr,s,-z,hinfo)

subplot(2,2,3),plot(pden(icntr,:)',-z(icntr,:)'),grid on,
 title('Density(z)','fontsize',13),hold on,label_cast(icntr,s,t,hinfo)

switch lower(plchoice)
case 'ss'
subplot(2,2,4),plot(sspd(icntr,:)',-z(icntr,:)'),grid on,
 title('Sound Speed(z)','fontsize',13),hold on,label_cast(icntr,pden,-z,hinfo)
case 'ts'
subplot(2,2,4),plot(s(icntr,:)',t(icntr,:)'),grid on,
 title('T/S(z)','fontsize',13),hold on,label_cast(icntr,pden,-z,hinfo)
end

if nstation <= 5
  h=suptitle(['Stations: ',num2str(hinfo(icntr,3)'),' ',plttl]);
else
  h=suptitle(plttl);
end

set(h,'fontsize',13)

orient tall

if(ifprint=='y')
   print -dpsc -Pmseasclr1
end

if(ifwrite=='y')
    if(pltype=='ps')
       outfile=[hydnam(1:nchar),'_four.ps'];
       print('-dpsc',outfile)
    end
    if(pltype=='pn')
       outfile=[hydnam(1:nchar),'_four.png'];
       print('-dpng',outfile)
    end
end

end
